const path = require('path');
const Postcss = require('postcss-smart-import');
const Cssnext = require('postcss-cssnext');
const Precss = require('precss');
const ResponsiveType = require('postcss-responsive-type');
const Apply = require('postcss-apply');

const PATHS = {
  entry: path.join(__dirname, '../src/index.js'),
  lib: path.join(__dirname, '../src'),
  build: path.join(__dirname, '../dist'),
};

const config = {
  mode: 'development',
  entry: {
    'vue-me': PATHS.entry,
  },
  output: {
    path: PATHS.build,
    library: 'vue-me',
    libraryTarget: 'umd',
  },
  resolve: {
    extensions: ['.ts', '.tsx', '.js'],
  },
  module: {
    rules: [
      { test: /\.tsx?$/, loader: 'ts-loader', exclude: /node_modules/ },
      {
        test: /\.js$/,
        include: PATHS.lib,

        use: {
          loader: 'babel-loader',
          options: {
            cacheDirectory: true,
          },
        },
      },
      {
        test: /\.(png|jp?g|svg|gif|ico)$/,
        use: {
          loader: 'url-loader',
        },
      },
      {
        test: /\.css$/,
        use: [
          'style-loader',
          { loader: 'css-loader', options: { importLoaders: 1, modules: false, localIdentName: 'purify_[name]-[local]-[hash:base64:6]' } },
          {
            loader: 'postcss-loader',
            options: {
              plugins: [
                new Postcss(),
                new Cssnext(),
                new Apply(),
                new Precss(),
                new ResponsiveType(),
              ],
            },
          },
        ],
      },
      {
        test: /\.scss$/,
        use: [
          'style-loader',
          { loader: 'css-loader', options: { importLoaders: 1, modules: true, localIdentName: 'purify_[name]-[local]-[hash:base64:6]' } },
          'sass-loader',
          {
            loader: 'postcss-loader',
            options: {
              plugins: [
                new Postcss(),
                new Cssnext(),
                new Apply(),
                new Precss(),
                new ResponsiveType(),
              ],
            },
          },
        ],
      },
    ],
  },
};

module.exports = config;
